# 
# Python example for TiePie engineering Handyscope HS3
# 
# Author:      TiePie engineering <support@tiepie.nl>
# Date:         2016-01-19
# 
# Execute:
#   python awg_example.py
#
# Description:
#   The AWG wil output for 30 seconds a Sinewave with the amplitide set to 1 Volt,
#   the DC offset is set to 2 Volt, the frequency is set to 5 kHz and the symmetry is 50%
#

from ctypes import *
import TiePie.Instruments
import time

def CheckReturn( value ):
  if value != TiePie.E_NO_ERRORS:
    print 'Error: %s' % TiePie.Instruments.DecodeErrorFlags( value )
    return False
  return True

# Create Handyscope HS3 object
TPdevice = TiePie.Instruments.Instrument( 'HS3' );

if CheckReturn( c_ushort( TPdevice.InitInstrument( 0 ) ).value ):
  # Switch generator hardware on
  CheckReturn( c_ushort( TPdevice.SetFuncGenOutputOn( 1 ) ).value )

  # Set signaltype to sine
  CheckReturn( c_ushort( TPdevice.SetFuncGenSignalType( TiePie.stSine ) ).value )
  
  # Set amplitude to 1 Volt
  CheckReturn( c_ushort( TPdevice.SetFuncGenAmplitude( c_double( 1 ) ) ).value )
  
  # Set DC offset at 2 Volt
  CheckReturn( c_ushort( TPdevice.SetFuncGenDCOffset( c_double( 2 ) ) ).value )
  
  # Set symmerty to 50%
  CheckReturn( c_ushort( TPdevice.SetFuncGenSymmetry( c_double( 50 ) ) ).value )
  
  # Set frequency to 5 kHz
  f = c_double( 5000 );
  CheckReturn( c_ushort( TPdevice.SetFuncGenFrequency( pointer( f ) ) ).value )
  
  # Start signal generation
  CheckReturn( c_short( TPdevice.SetFuncGenEnable( 1 ) ).value )
  
  # wait for 30 sec
  time.sleep( 30 )
  
  # Stop signal generation
  CheckReturn( c_short( TPdevice.SetFuncGenEnable( 0 ) ).value )
  
  # Switch generator hardware off
  CheckReturn( c_ushort( TPdevice.SetFuncGenOutputOn( 0 ) ).value )
  
  # close instrument
  TPdevice.ExitInstrument()
