# 
# Python example for TiePie engineering Handyscope HS3
# 
# Author:      TiePie engineering <support@tiepie.nl>
# Date:         2016-01-19
#
# Note:
#   Connect the AWG output to Ch1
#
# Execute:
#   python scope_awg_example.py > one_shot.csv
#
# Description:
#   The instrument will measure 10000 samples at 10 kHz, sensitivity is set to 2 Volt, coupling is set to DC.
#   The trigger is set to Ch1 at 0 Volt, trigger type = rising edge
#   All data will be outputed as CSV data.
#   While measuring the signal type of the AWG is changed.
#

from ctypes import *
import TiePie.Instruments
import time

def CheckReturn( value ):
  if value != TiePie.E_NO_ERRORS:
    print 'Error: %s' % TiePie.Instruments.DecodeErrorFlags( value )
    return False
  return True

# Create Handyscope HS3 object
TPdevice = TiePie.Instruments.Instrument( 'HS3' );

if CheckReturn( c_ushort( TPdevice.InitInstrument( 0 ) ).value ):
   
  # Switch generator hardware on
  CheckReturn( c_ushort( TPdevice.SetFuncGenOutputOn( 1 ) ).value )

  # Set signaltype to sine
  CheckReturn( c_ushort( TPdevice.SetFuncGenSignalType( TiePie.stSine ) ).value )
  
  # Set amplitude to 1.5 Volt
  CheckReturn( c_ushort( TPdevice.SetFuncGenAmplitude( c_double( 1.5 ) ) ).value )
  
  # Set DC offset at 0 Volt
  CheckReturn( c_ushort( TPdevice.SetFuncGenDCOffset( c_double( 0 ) ) ).value )
  
  # Set symmerty to 50%
  CheckReturn( c_ushort( TPdevice.SetFuncGenSymmetry( c_double( 50 ) ) ).value )
  
  # Set frequency to 50 Hz
  f = c_double( 50 );
  CheckReturn( c_ushort( TPdevice.SetFuncGenFrequency( pointer( f ) ) ).value )
  
  # Start signal generation
  CheckReturn( c_short( TPdevice.SetFuncGenEnable( 1 ) ).value )
  
  # Measure on Ch1
  CheckReturn( c_ushort( TPdevice.SetMeasureMode( TiePie.mmCh1 ) ).value )
  
  # Set record length to 10000
  CheckReturn( c_ushort( TPdevice.SetRecordLength( 10000 ) ).value )
  
  # Set post samples to 10000
  CheckReturn( c_ushort( TPdevice.SetPostSamples( 10000 ) ).value )
  
  # Set sample frequency to 10 kHz
  dSampleFreq = c_double( 10000 )    
  CheckReturn( c_ushort( TPdevice.SetSampleFrequencyF( pointer( dSampleFreq ) ) ).value )
  
  # Set sensetivity to 2 Volt
  # Set coupling to DC
  dSens = c_double( 2 )
  pdSens = pointer( dSens )
  CheckReturn( c_ushort( TPdevice.SetSensitivity( TiePie.Ch1 , pdSens ) ).value )
  CheckReturn( c_ushort( TPdevice.SetCoupling( TiePie.Ch1 , TiePie.ctDC ) ).value )
  
  # Set trigger to ch1
  CheckReturn( c_ushort( TPdevice.SetTriggerSource( TiePie.tsCh1 ) ).value )
  
  # Set trigger type to rising edge
  CheckReturn( c_ushort( TPdevice.SetTriggerMode( TiePie.tmRising ) ).value )
  
  # Set trigger level to 0 Volt
  CheckReturn( c_ushort( TPdevice.SetTriggerLevel( TiePie.Ch1 , c_double( 0 ) ) ).value )
  
  # Start measurement
  #   note: This is a non-blocking function (python will continue)
  CheckReturn( c_ushort( TPdevice.ADC_Start() ).value )
  
  # wait for 0.5 sec
  time.sleep( 0.5 )
  
  # Set signaltype to triangle
  CheckReturn( c_ushort( TPdevice.SetFuncGenSignalType( TiePie.stTriangle ) ).value ) 
  
  # Loop until measurement is done
  while TPdevice.ADC_Ready() == 0:
    # Normaly we should do something usefull here
    time.sleep( 0.01 )
  
  # disable output 
  CheckReturn( c_ushort( TPdevice.SetFuncGenEnable( 0 ) ).value )
  
  # Get Recordlength
  dwRecordLength = TPdevice.GetRecordLength()
  
  # define type darData to store measured data
  darData    = (c_double * dwRecordLength)
  
  # create 2D array
  darDataCh = darData()
  
  # Get data from DLL
  CheckReturn( c_ushort( TPdevice.ADC_GetDataVoltCh( TiePie.Ch1 , darDataCh ) ).value )
  
  # print header
  print "Sample Number;Channel 1"
  
  # print data
  for s in range( dwRecordLength ):
    print "%u;%f" % ( ( s + 1 ) , darDataCh[ s ] )
  
  # Switch generator hardware off
  CheckReturn( c_ushort( TPdevice.SetFuncGenOutputOn( 0 ) ).value )

  # close instrument
  TPdevice.ExitInstrument()
