# 
# Python example for TiePie engineering Handyscope HS3
# 
# Author:      TiePie engineering <support@tiepie.nl>
# Date:         2007-01-04
#
# Execute:
#   python scope_example.py > one_shot.csv
# 
# Description:
#   The instrument will measure 1000 samples at 100 kHz, sensitivity is set to 8 Volt, coupling is set to DC.
#   The trigger is set to Ch1 at 0 Volt, trigger type = rising edge
#   All data will be outputed as CSV data.
#

from ctypes import *
import TiePie.Instruments
import time

def CheckReturn( value ):
  if value != TiePie.E_NO_ERRORS:
    print 'Error: %s' % TiePie.Instruments.DecodeErrorFlags( value )
    return False
  return True

# Create Handyscope HS3 object
TPdevice = TiePie.Instruments.Instrument( 'HS3' );

if CheckReturn( c_ushort( TPdevice.InitInstrument( 0 ) ).value ):

  # Get number of channels
  iChannelCount = 0
  wChannelCount = c_ushort( 0 )
  CheckReturn( c_ushort( TPdevice.GetNrChannels( pointer( wChannelCount ) ) ).value )
  iChannelCount = wChannelCount.value

  # Measure on All channels
  CheckReturn( c_ushort( TPdevice.SetMeasureMode( pow( 2 , iChannelCount ) - 1 ) ).value )
  
  # Set record length to 1000
  CheckReturn( c_ushort( TPdevice.SetRecordLength( 1000 ) ).value )
  
  # Set post samples to 1000
  CheckReturn( c_ushort( TPdevice.SetPostSamples( 1000 ) ).value )
  
  # Set sample frequency to 100 kHz
  dSampleFreq = c_double( 100000 )    
  CheckReturn( c_ushort( TPdevice.SetSampleFrequencyF( pointer( dSampleFreq ) ) ).value )
  
  # Set sensetivity to 8 Volt
  # Set coupling to DC
  dSens = c_double( 8 )
  pdSens = pointer( dSens )
  for ch in range( iChannelCount ):
    CheckReturn( c_ushort( TPdevice.SetSensitivity( ch + 1 , pdSens ) ).value )
    CheckReturn( c_ushort( TPdevice.SetCoupling( ch + 1 , TiePie.ctDC ) ).value )
  
  # Set trigger to ch1
  CheckReturn( c_ushort( TPdevice.SetTriggerSource( TiePie.tsCh1 ) ).value )
  
  # Set trigger type to rising edge
  CheckReturn( c_ushort( TPdevice.SetTriggerMode( TiePie.tmRising ) ).value )
    
  # Set trigger level to 0 Volt
  CheckReturn( c_ushort( TPdevice.SetTriggerLevel( TiePie.Ch1 , c_double( 0 ) ) ).value )
  
  # Start measurement
  #   note: This is a non-blocking function (python will continue)
  CheckReturn( c_ushort( TPdevice.ADC_Start() ).value )
  
  # Loop until measurement is done
  while TPdevice.ADC_Ready() == 0:
    # Normaly we should do something usefull here
    time.sleep( 0.01 )
  
  # Get Recordlength
  dwRecordLength = TPdevice.GetRecordLength()
  
  # define type darData to store measured data
  darData    = (c_double * dwRecordLength) * iChannelCount
  
  # create 2D array
  darDataCh = darData()
  
  # Get data from DLL
  for ch in range( iChannelCount ):
    CheckReturn( c_ushort( TPdevice.ADC_GetDataVoltCh( ch + 1 , darDataCh[ ch ] ) ).value )
  
  # print header
  header = "Sample Number"
  for ch in range( iChannelCount ):
    header += ";Channel %u" % ( ch + 1 )
  print header
  
  # print data
  for s in range( dwRecordLength ):
    line = "%u" % ( s + 1 )
    for ch in range( iChannelCount ):
      line += ";%f" % darDataCh[ ch ][ s ]
    print line
  
  # close instrument
  TPdevice.ExitInstrument()
