#
# Python example for TiePie engineering Handyscope HS4 (DIFF) streaming mode
#
# Author:      TiePie engineering <support@tiepie.nl>
# Date:         2011-01-13
#
# Note:
#   You need to install PyWin32 package it can be downloaded from: http://sourceforge.net/projects/pywin32/files/pywin32
#
# Execute:
#   python HS4_stream_example.py
#
# Description:
#   The Handyscope HS4 (DIFF) will measure 1024 samples at 1 kHz, sensitivity is set to 2 Volt, coupling is set to DC.
#   All data will be outputed as CSV data.
#

from ctypes import *
import win32event
import TiePie.Instruments
import time

def CheckReturn( value ):
  if value != TiePie.E_NO_ERRORS:
    print 'Error: %s' % TiePie.Instruments.DecodeErrorFlags( value )
    return False
  return True

def ProcessData( HS4 ):
  # Get Recordlength
  dwRecordLength = HS4.GetRecordLength()

  # define type darData to store measured data
  darData = (c_double * dwRecordLength)

  # create 2D array
  darDataCh = darData()

  # Get data from DLL
  CheckReturn( c_ushort( HS4.ADC_GetDataVoltCh( TiePie.Ch1 , darDataCh ) ).value )

  # print header
  print "Sample Number;Channel 1"

  # print data
  for s in range( dwRecordLength ):
    print "%u;%f" % ( ( s + 1 ) , darDataCh[ s ] )

# Create Handyscope HS4 (DIFF) object
HS4 = TiePie.Instruments.Instrument( 'HS4' );

if CheckReturn( c_ushort( HS4.InitInstrument( 0 ) ).value ):

  # Measure on Ch1
  CheckReturn( c_ushort( HS4.SetMeasureMode( TiePie.mmCh1 ) ).value )

  # Set record length to 1024
  CheckReturn( c_ushort( HS4.SetRecordLength( 1024 ) ).value )

  # Set post samples to 1024
  CheckReturn( c_ushort( HS4.SetPostSamples( 1024 ) ).value )

  # Set sample frequency to 1 kHz
  dSampleFreq = c_double( 1000 )
  CheckReturn( c_ushort( HS4.SetSampleFrequencyF( pointer( dSampleFreq ) ) ).value )

  # Set mode to stream
  CheckReturn( c_ushort( HS4.SetTransferMode( TiePie.tmStream ) ).value )

  # Set sensetivity to 2 Volt
  # Set coupling to DC
  dSens = c_double( 2 )
  pdSens = pointer( dSens )
  CheckReturn( c_ushort( HS4.SetSensitivity( TiePie.Ch1 , pdSens ) ).value )
  CheckReturn( c_ushort( HS4.SetCoupling( TiePie.Ch1 , TiePie.ctDC ) ).value )

  # Create and set event
  DataReadyEvent = win32event.CreateEvent( None , 0 , 0 , None )
  CheckReturn( c_ushort( HS4.SetDataReadyEvent( DataReadyEvent.handle ) ).value )

  # Start measuring
  #   note: This is a non-blocking function (python will continue)
  CheckReturn( c_ushort( HS4.ADC_Start() ).value )

  while True:
    rc = win32event.WaitForSingleObject( DataReadyEvent , 200 ) # 200ms timeout

    if rc == win32event.WAIT_OBJECT_0:
      #print 'WAIT_OBJECT_0'
      ProcessData( HS4 )
    #elif rc == win32event.WAIT_ABANDONED:
    #  print 'WAIT_ABANDONED'
    #elif rc == win32event.WAIT_TIMEOUT:
    #  print 'WAIT_TIMEOUT'

  # Stop measuring
  CheckReturn( c_ushort( HS4.ADC_Abort() ).value )

  # close instrument
  HS4.ExitInstrument()
